@@ -22,4 +22,11 @@ class ActionEndpoint(APIEndpoint):
         status, headers, resp_json = self.api.post( f'{self.endpoint}/conversation', data={'call-1' : { 'origin': sipaccount_id, 'destination': call_to }})
         if status > 299: return construct_error_from_data(resp_json)
         
-        return construct_object_from_data(resp_json[0])
\ No newline at end of file
+        return construct_object_from_data(resp_json[0])
+    
+    def end_call(self, call_id) -> BaseModel:
+        
+        status, headers, resp_json = self.api.delete( f'{self.endpoint}/conversation', data={'ID' : call_id})
+        if status > 299: return construct_error_from_data(resp_json)
+        
+        return construct_object_from_data(resp_json)
\ No newline at end of file
